@@ -6,3 +6,9 @@ lapply(list.files(system.file("testthat", package = "mlr3"), pattern = "^helper.
                   full.names = TRUE), source)
 lapply(list.files(system.file("testthat", package = "mlr3proba"), pattern = "^helper.*\\.[rR]",
                   full.names = TRUE), source)
+
+assert_ro_binding = function (rhs) {
+  if (!missing(rhs)) {
+    stopf("Field/Binding is read-only")
+  }
+}
